=== modified file 'drizzled/constrained_value.h'
--- drizzled/constrained_value.h	2010-09-14 07:47:50 +0000
+++ drizzled/constrained_value.h	2010-10-19 21:51:42 +0000
@@ -30,46 +30,45 @@
 template<class T>
 class constrained_value
 {
+  T m_val;
+protected:
+
+  virtual constrained_value<T>& set_value(const constrained_value<T>& rhs)= 0;
+  virtual constrained_value<T>& set_value(T rhs)= 0;
+
 public:
-  constrained_value<T>(T in_value= 0,
-                       T in_max_val= std::numeric_limits<T>::max(),
-                       T in_min_val= std::numeric_limits<T>::min(),
-                       int in_align_to= 1) :
-    m_val(in_value),
-    m_max_val(in_max_val),
-    m_min_val(in_min_val),
-    m_align_to(in_align_to)
-  { }
-
-  constrained_value<T>(const constrained_value<T>& old) :
-    m_val(old.m_val),
-    m_max_val(old.m_max_val),
-    m_min_val(old.m_min_val),
-    m_align_to(old.m_align_to)
-  { }
+  explicit constrained_value<T>(T in_value= 0) :
+    m_val(in_value)
+  { }
+
+  virtual ~constrained_value<T>()
+  {}
+
+  operator T() const
+  {
+    return m_val;
+  }
 
   constrained_value<T>& operator=(const constrained_value<T>& rhs)
   {
-    (*this)= rhs.m_val;
-    return *this;
+    return set_value(rhs);
   }
 
   constrained_value<T>& operator=(T rhs)
   {
-    if ((rhs > m_max_val) || (rhs < m_min_val))
-    {
-      boost::throw_exception(boost::program_options::validation_error(boost::program_options::validation_error::invalid_option_value));
-    }
-    rhs-= rhs % m_align_to;
-    m_val= rhs;
-    return *this;
+    return set_value(rhs);
   }
 
-  operator T()
+  T getVal() const
   {
     return m_val;
   }
 
+  void setVal(T in_val)
+  {
+    m_val= in_val;
+  }
+
   template<class CharT, class Traits>
   friend std::basic_istream<CharT,Traits>&
   operator>>(std::basic_istream<CharT,Traits>& is,
@@ -84,37 +83,55 @@
   friend
   std::ostream& operator<<(std::ostream& os, const constrained_value<T>& v)
   {
-    os << v.m_val;
+    os << v.getVal();
     return os;
   }
-
-private:
-  T m_val;
-  T m_max_val;
-  T m_min_val;
-  int m_align_to;
-};
+};
+
+template<class T, uint64_t MAXVAL=UINT64_MAX, int64_t MINVAL=INT64_MIN, int ALIGN=1>
+class constrained_check :
+  public constrained_value<T>
+{
+public:
+  constrained_check<T,MAXVAL,MINVAL,ALIGN>(T in_value= 0) :
+    constrained_value<T>(in_value)
+  { }
+
+protected:
+  constrained_value<T>& set_value(const constrained_value<T>& rhs)
+  {
+    return set_value(rhs.getVal());
+  }
+
+  constrained_value<T>& set_value(T rhs)
+  {
+    if ((rhs > MAXVAL) || (rhs < MINVAL))
+    {
+      boost::throw_exception(boost::program_options::validation_error(boost::program_options::validation_error::invalid_option_value));
+    }
+    rhs-= rhs % ALIGN;
+    setVal(rhs);
+    return *this;
+  }
+
+
+};
+
+typedef constrained_check<uint32_t,65535,1> back_log_constraints;
 
 } /* namespace drizzled */
 
 template<class T>
 void validate(boost::any& v,
               const std::vector<std::string>& values,
-              drizzled::constrained_value<T>, int)
+              drizzled::constrained_value<T> val, int)
 {
   boost::program_options::validators::check_first_occurrence(v);
   const std::string& s= boost::program_options::validators::get_single_string(values);
 
-  drizzled::constrained_value<T> &val= boost::any_cast<T>(v);
-  try
-  {
-    val= boost::lexical_cast<T>(s);
-  }
-  catch (...)
-  {
-    boost::throw_exception(boost::program_options::validation_error(boost::program_options::validation_error::invalid_option_value));
-  }
+  val= boost::lexical_cast<T>(s);
   v= boost::any(val);
 }
 
+
 #endif /* DRIZZLED_CONSTRAINED_VALUE_H */

=== modified file 'drizzled/drizzled.cc'
--- drizzled/drizzled.cc	2010-10-14 07:05:23 +0000
+++ drizzled/drizzled.cc	2010-10-19 21:51:42 +0000
@@ -125,6 +125,7 @@
 #endif
 
 #include "drizzled/internal/my_pthread.h"			// For thr_setconcurency()
+#include "drizzled/constrained_value.h"
 
 #include <drizzled/gettext.h>
 
@@ -244,7 +245,7 @@
 uint32_t dropping_tables, ha_open_options;
 uint32_t tc_heuristic_recover= 0;
 uint64_t session_startup_options;
-uint32_t back_log;
+back_log_constraints back_log(50);
 uint32_t server_id;
 uint64_t table_cache_size;
 size_t table_def_size;
@@ -749,16 +750,6 @@
   global_system_variables.completion_type= in_completion_type;
 }
 
-static void check_limits_back_log(uint32_t in_back_log)
-{
-  back_log= 50;
-  if (in_back_log < 1 || in_back_log > 65535)
-  {
-    cout << N_("Error: Invalid Value for back_log");
-    exit(-1);
-  }
-  back_log= in_back_log;
-}
 
 static void check_limits_dpi(uint32_t in_div_precincrement)
 {
@@ -1294,7 +1285,7 @@
   N_("Run drizzled daemon as user."))  
   ("version,V", 
   N_("Output version information and exit."))
-  ("back-log", po::value<uint32_t>(&back_log)->default_value(50)->notifier(&check_limits_back_log),
+  ("back-log", po::value<back_log_constraints>(&back_log),
   N_("The number of outstanding connection requests Drizzle can have. This "
      "comes into play when the main Drizzle thread gets very many connection "
      "requests in a very short time."))
@@ -1444,7 +1435,18 @@
   /* TODO: here is where we should add a process_env_vars */
 
   /* We need a notify here so that plugin_init will work properly */
-  po::notify(vm);
+  try
+  {
+    po::notify(vm);
+  }
+  catch (po::validation_error &err)
+  {
+    errmsg_printf(ERRMSG_LVL_ERROR,  
+                  _("%s: %s.\n"
+                    "Use --help to get a list of available options\n"),
+                  internal::my_progname, err.what());
+    unireg_abort(1);
+  }
   /* At this point, we've read all the options we need to read from files and
      collected most of them into unknown options - now let's load everything
   */
@@ -1470,6 +1472,14 @@
     po::store(final_parsed, vm);
 
   }
+  catch (po::validation_error &err)
+  {
+    errmsg_printf(ERRMSG_LVL_ERROR,
+                  _("%s: %s.\n"
+                    "Use --help to get a list of available options\n"),
+                  internal::my_progname, err.what());
+    unireg_abort(1);
+  }
   catch (po::invalid_command_line_syntax &err)
   {
     errmsg_printf(ERRMSG_LVL_ERROR,
@@ -1486,7 +1496,18 @@
     unireg_abort(1);
   }
 
-  po::notify(vm);
+  try
+  {
+    po::notify(vm);
+  }
+  catch (po::validation_error &err)
+  {
+    errmsg_printf(ERRMSG_LVL_ERROR,  
+                  _("%s: %s.\n"
+                    "Use --help to get a list of available options\n"),
+                  internal::my_progname, err.what());
+    unireg_abort(1);
+  }
 
   get_options();
 

=== modified file 'drizzled/plugin/listen_tcp.cc'
--- drizzled/plugin/listen_tcp.cc	2010-06-18 19:20:00 +0000
+++ drizzled/plugin/listen_tcp.cc	2010-10-19 21:51:42 +0000
@@ -22,6 +22,7 @@
 #include <drizzled/error.h>
 #include <drizzled/plugin/listen_tcp.h>
 #include <drizzled/errmsg_print.h>
+#include <drizzled/constrained_value.h>
 
 #include <cstdio>
 #include <unistd.h>
@@ -37,7 +38,7 @@
 
 namespace drizzled
 {
-extern uint32_t back_log;
+extern back_log_constraints back_log;
 extern uint32_t drizzled_bind_timeout;
 
 

=== modified file 'drizzled/session.h'
--- drizzled/session.h	2010-10-19 13:38:53 +0000
+++ drizzled/session.h	2010-10-19 21:51:42 +0000
@@ -167,7 +167,8 @@
 
 struct system_variables
 {
-  system_variables() {};
+  system_variables()
+  {};
   /*
     How dynamically allocated system variables are handled:
 

=== modified file 'drizzled/set_var.cc'
--- drizzled/set_var.cc	2010-10-15 05:16:32 +0000
+++ drizzled/set_var.cc	2010-10-19 21:51:42 +0000
@@ -63,6 +63,7 @@
 #include "drizzled/pthread_globals.h"
 #include "drizzled/charset.h"
 #include "drizzled/transaction_services.h"
+#include "drizzled/constrained_value.h"
 
 #include <cstdio>
 #include <map>
@@ -139,7 +140,7 @@
 
 static sys_var_size_t_ptr sys_thread_stack_size("thread_stack",
                                                       &my_thread_stack_size);
-static sys_var_uint32_t_ptr sys_back_log("back_log", &back_log);
+static sys_var_constrained_value<uint32_t> sys_back_log("back_log", back_log);
 
 static sys_var_session_uint64_t	sys_bulk_insert_buff_size("bulk_insert_buffer_size",
                                                           &system_variables::bulk_insert_buff_size);

=== modified file 'drizzled/set_var.h'
--- drizzled/set_var.h	2010-10-17 15:01:30 +0000
+++ drizzled/set_var.h	2010-10-19 21:51:42 +0000
@@ -75,7 +75,7 @@
 extern uint32_t global_thread_id;
 extern uint64_t table_cache_size;
 extern uint64_t max_connect_errors;
-extern uint32_t back_log;
+extern back_log_constraints back_log;
 extern uint32_t ha_open_options;
 extern char *drizzled_bind_host;
 extern uint32_t dropping_tables;

=== modified file 'unittests/constrained_value.cc'
--- unittests/constrained_value.cc	2010-09-14 07:47:50 +0000
+++ unittests/constrained_value.cc	2010-10-19 21:51:42 +0000
@@ -20,9 +20,12 @@
 
 #include "config.h"
 
+#include <string>
+
 #include <gtest/gtest.h>
 
 #include <drizzled/constrained_value.h>
+#include <boost/lexical_cast.hpp>
 
 using namespace drizzled;
 
@@ -30,7 +33,7 @@
 
 TEST(constrained_value, raw_usage)
 {
-  constrained_value<uint64_t> val(1, 1024, 1, 10);
+  constrained_check<uint64_t,1024,1,10> val(1);
 
   EXPECT_EQ(UINT64_C(1), (uint64_t)val);
 
@@ -42,3 +45,13 @@
   EXPECT_EQ(20, (uint64_t)val);
 }
 
+TEST(constrained_value, lexical_cast_usage)
+{
+  constrained_check<uint64_t,1024,1,10> val(1);
+
+  std::string string_val= boost::lexical_cast<std::string>(val);
+
+  EXPECT_EQ(std::string("1"), string_val);
+}
+
+

